@@ -9,7 +9,8 @@
  */
 
 #include <R.h>
-#include <R_ext/Applic.h> /* R blas declarations */
+#include <R_ext/Applic.h> /* No longer contains R blas declarations */
+#include <R_ext/BLAS.h> /* New R blas declarations */
 
 #include "cblas.h"
 double cblas_dasum( const int N, const double *X, const int incX) 
